---
title: ANSYS 
#tags:
keywords: software, ansys, slurm, interactive, rsm, pmodules, overlay, overlays
last_updated: 07 September 2022
summary: "This document describes how to load and use ANSYS in the Merlin6 cluster"
sidebar: merlin6_sidebar
permalink: /merlin6/ansys.html
---

This document describes generic information of how to load and run ANSYS software in the Merlin cluster

## ANSYS software in Pmodules

The ANSYS software can be loaded through **[PModules](/merlin6/using-modules.html)**.

The default ANSYS versions are loaded from the central PModules repository. 
However, there are some known problems that can pop up when using some specific ANSYS packages in advanced mode.
Due to this, and also to improve the interactive experience of the user, ANSYS has been also installed in the 
Merlin high performance storage and we have made it available from Pmodules. 

### Loading Merlin6 ANSYS

For loading the Merlin6 ANSYS software, one needs to run Pmodules v1.1.4 or newer, and then use a specific repository 
(called **`overlay_merlin`**) which is ***only available from the Merlin cluster***:

```bash
module load Pmodules/1.1.6
module use overlay_merlin
```

Once `overlay_merlin` is invoked, it will disable central ANSYS installations with the same version, which will be replaced
by the local ones in Merlin. Releases from the central Pmodules repository which have not a local installation will remain 
visible. For each ANSYS release, one can identify where it is installed by searching ANSYS in PModules with the `--verbose` 
option. This will show the location of the different ANSYS releases as follows:
* For ANSYS releases installed in the central repositories, the path starts with `/opt/psi`
* For ANSYS releases installed in the Merlin6 repository (and/or overwritting the central ones), the path starts with `/data/software/pmodules`

<details>
<summary>[Example] Loading ANSYS from the Merlin6 PModules repository</summary>
<pre class="terminal code highlight js-syntax-highlight plaintext" lang="plaintext" markdown="false">
(base) ❄ [caubet_m@merlin-l-001:/data/user/caubet_m]# module load Pmodules/1.1.6
module load: unstable module has been loaded -- Pmodules/1.1.6

(base) ❄ [caubet_m@merlin-l-001:/data/user/caubet_m]# module use merlin_overlay

(base) ❄ [caubet_m@merlin-l-001:/data/user/caubet_m]# module search ANSYS --verbose

Module         Rel.stage  Group        Dependencies/Modulefile
-------------------------------------------------------------------------------------------------------------------------------------------------------------------------
ANSYS/2019R3   stable     Tools        dependencies: 
                                       modulefile:   /data/software/pmodules/Tools/modulefiles/ANSYS/2019R3
ANSYS/2020R1   stable     Tools        dependencies: 
                                       modulefile:   /opt/psi/Tools/modulefiles/ANSYS/2020R1
ANSYS/2020R1-1 stable     Tools        dependencies: 
                                       modulefile:   /opt/psi/Tools/modulefiles/ANSYS/2020R1-1
ANSYS/2020R2   stable     Tools        dependencies: 
                                       modulefile:   /data/software/pmodules/Tools/modulefiles/ANSYS/2020R2
ANSYS/2021R1   stable     Tools        dependencies: 
                                       modulefile:   /data/software/pmodules/Tools/modulefiles/ANSYS/2021R1
ANSYS/2021R2   stable     Tools        dependencies: 
                                       modulefile:   /data/software/pmodules/Tools/modulefiles/ANSYS/2021R2
</pre>
</details>


{{site.data.alerts.tip}} Please <b>only use Merlin6 ANSYS installations from `overlay_merlin`</b> in the Merlin cluster.
{{site.data.alerts.end}}

## ANSYS Documentation by product

### ANSYS RSM

**ANSYS Remote Solve Manager (RSM)** is used by ANSYS Workbench to submit computational jobs to HPC clusters directly from Workbench on your desktop.
Therefore, PSI workstations with direct access to Merlin can submit jobs by using RSM.

For further information, please visit the **[ANSYS RSM](/merlin6/ansys-rsm.html)** section.

### ANSYS Fluent

For further information, please visit the **[ANSYS RSM](/merlin6/ansys-fluent.html)** section.

### ANSYS CFX

For further information, please visit the **[ANSYS RSM](/merlin6/ansys-cfx.html)** section.

### ANSYS MAPDL

For further information, please visit the **[ANSYS RSM](/merlin6/ansys-mapdl.html)** section.
