---
title: Running Paraview
#tags:
last_updated: 03 December 2020
keywords: software, paraview, mesa, OpenGL, interactive
summary: "This document describes how to run ParaView in the Merlin6 cluster"
sidebar: merlin6_sidebar
permalink: /merlin6/paraview.html
---

## Requirements

**[NoMachine](/merlin6/nomachine.html)** is the official **strongly recommended and supported** tool for running *ParaView*.
Consider that running over SSH (X11-Forwarding needed) is very slow, but also configuration might not work as it also depends
on the client configuration (Linux workstation/laptop, Windows with XMing, etc.). Hence, please **avoid running Paraview over SSH**.
The only exception for running over SSH is when running it as a job from a NoMachine client.

## ParaView

### PModules

Is strongly recommended the use of the latest ParaView version available in PModules. In example, for loading **paraview**:

```bash
module use unstable
module load paraview/5.8.1
```

### Running ParaView

For running ParaView, one can run it with **VirtualGL** to take advantatge of the GPU card located on each login node. For that, once loaded, you can start **paraview** as follows:

```bash
vglrun paraview
```

Alternatively, one can run **paraview** with *mesa* support with the below command. This can be useful when running on CPU computing nodes (with `srun` / `salloc`) 
which have no graphics card (and where `vglrun` is not possible):

```bash
paraview-mesa paraview
```

#### Running older versions of ParaView

Older versions of ParaView available in PModules (i.e. *paraview/5.0.1* and *paraview/5.4.1*) might require a different command
for running paraview with **Mesa** support. The command is the following:

```bash
# Warning: only for Paraview 5.4.1 and older
paraview --mesa
```

#### Running ParaView interactively in the batch system

One can run ParaView interactively in the CPU cluster as follows:

```bash
# First, load module. In example: "module load paraview/5.8.1"
srun --pty --x11 --partition=general --ntasks=1 paraview-mesa paraview
```

One can change the partition, number of tasks or specify extra parameters to `srun` if needed.
