---
title: Requesting a Merlin Project
#tags:
keywords: merlin project, project, snow, service now
last_updated: 07 September 2022
#summary: ""
sidebar: merlin7_sidebar
permalink: /merlin7/request-project.html
---

A project owns its own storage area in Merlin, which can be accessed by other group members.

Projects can receive a higher storage quota than user areas and should be the primary way of organizing bigger storage requirements
in a multi-user collaboration.

Access to a project's directories is governed by project members belonging to a common **Unix group**. You may use an existing
Unix group or you may have a new Unix group created especially for the project. The **project responsible** will be the owner of
the Unix group (*this is important*)!

This document explains how to request new Unix group, to request membership for existing groups, and the procedure for requesting a Merlin project.

## About Unix groups

Before requesting a Merlin project, it is important to have a Unix group that can be used to grant access to it to different members 
of the project.

Unix groups in the PSI Active Directory (which is the PSI central database containing user and group information, and more) are defined by the `unx-` prefix, followed by a name.
In general, PSI employees working on Linux systems (including HPC clusters, like Merlin) can request for a non-existing Unix group, and can become responsible for managing it. 
In addition, a list of administrators can be set. The administrators, together with the group manager, can approve or deny membership requests. Further information about this topic
is covered in the [Linux Documentation - Services Admin Guides: Unix Groups / Group Management](https://linux.psi.ch/services-admin-guide/unix_groups.html), managed by the Central Linux Team.

To gran access to specific Merlin project directories, some users may require to be added to some specific **Unix groups**:
  * Each Merlin project (i.e. `/data/project/{bio|general}/$projectname`) or experiment (i.e. `/data/experiment/$experimentname`) directory has access restricted by ownership and group membership (with a very few exceptions allowing public access).
  * Users requiring access to a specific restricted project or experiment directory have to request membership for the corresponding Unix group owning the directory.

### Requesting a new Unix group

**If you need a new Unix group** to be created, you need to first get this group through a separate 
**[PSI Service Now ticket](https://psi.service-now.com/psisp)**. **Please use the following template.**
You can also specify the login names of the initial group members and the **owner** of the group.
The owner of the group is the person who will be allowed to modify the group.

* Please open an *Incident Request* with subject:
   ```
   Subject: Request for new unix group xxxx
   ```

* and base the text field of the request on this template
   ```
   Dear HelpDesk
   
   I would like to request a new unix group.
   
   Unix Group Name: unx-xxxxx
   Initial Group Members: xxxxx, yyyyy, zzzzz, ...
   Group Owner: xxxxx
   Group Administrators: aaaaa, bbbbb, ccccc, ....

   Best regards,
   ```

### Requesting Unix group membership

Existing Merlin projects have already a Unix group assigned. To have access to a project, users must belong to the proper **Unix group** owning that project.
Supervisors should inform new users which extra groups are needed for their project(s). If this information is not known, one can check the permissions for that directory. In example:
```bash
(base) ❄ [caubet_m@merlin-l-001:/data/user/caubet_m]# ls -ltrhd /data/project/general/$projectname
(base) ❄ [caubet_m@merlin-l-001:/data/user/caubet_m]# ls -ltrhd /data/project/bio/$projectname
```

Requesting membership for a specific Unix group *has to be done* with the corresponding **[Request Linux Group Membership](https://psi.service-now.com/psisp?id=psi_new_sc_cat_item&sys_id=84f2c0c81b04f110679febd9bb4bcbb1)** form, available in the [PSI Service Now Service Catalog](https://psi.service-now.com/psisp).

![Example: Requesting Unix Group membership]({{ "/images/Access/01-request-unx-group-membership.png" }})

Once submitted, the responsible of the Unix group has to approve the request.

**Important note**: Requesting access to specific Unix Groups will require validation from the responsible of the Unix Group. If you ask for inclusion in many groups it may take longer, since the fulfillment of the request will depend on more people.

Further information can be found in the [Linux Documentation - Services User guide: Unix Groups / Group Management](https://linux.psi.ch/services-user-guide/unix_groups.html)

### Managing Unix Groups

Other administration operations on Unix Groups it's mainly covered in the [Linux Documentation - Services Admin Guides: Unix Groups / Group Management](https://linux.psi.ch/services-admin-guide/unix_groups.html), managed by the Central Linux Team.

## Requesting a Merlin project

Once a Unix group is available, a Merlin project can be requested.
To request a project, please provide the following information in a **[PSI Service Now ticket](https://psi.service-now.com/psisp)**

* Please open an *Incident Request* with subject:
   ```
   Subject: [Merlin7] Project Request for project name xxxxxx
   ```

* and base the text field of the request on this template
   ```
   Dear HelpDesk
   
   I would like to request a new Merlin7 project.
   
   Project Name: xxxxx
   UnixGroup: xxxxx    # Must be an existing Unix Group

   The project responsible is the Owner of the Unix Group.
   If you need a storage quota exceeding the defaults, please provide a description
   and motivation for the higher storage needs:
   
   Storage Quota: 1TB with a maximum of 1M Files
   Reason: (None for default 1TB/1M)

   Best regards,
   ```

The **default storage quota** for a project is 1TB (with a maximal *Number of Files* of 1M). If you need a larger assignment, you
need to request this and provide a description of your storage needs.

## Further documentation

Further information it's also available in the Linux Central Documentation:
* [Unix Group / Group Management for users](https://linux.psi.ch/services-user-guide/unix_groups.html)
* [Unix Group / Group Management for group managers](https://linux.psi.ch/services-admin-guide/unix_groups.html)

**Special thanks** to the **Linux Central Team** and **AIT** to make this possible.
