---
title: Connecting from a MacOS Client
#tags:
keywords: MacOS, mac os, mac, connecting, client, configuration, SSH, X11
last_updated: 07 September 2022
summary: "This document describes a recommended setup for a MacOS client."
sidebar: merlin7_sidebar
permalink: /merlin7/connect-from-macos.html
---

## SSH without X11 Forwarding

This is the standard method. Official X11 support is provided through [NoMachine](/merlin7/nomachine.html).
For normal SSH sessions, use your SSH client as follows:

```bash
ssh $username@login001.merlin7.psi.ch
ssh $username@login002.merlin7.psi.ch
```

## SSH with X11 Forwarding

### Requirements

For running SSH with X11 Forwarding in MacOS, one needs to have a X server running in MacOS.
The official X Server for MacOS is **[XQuartz](https://www.xquartz.org/)**. Please ensure
you have it running before starting a SSH connection with X11 forwarding.

### SSH with X11 Forwarding in MacOS

Official X11 support is through NoMachine. Please follow the document
[{Job Submission -> Interactive Jobs}](/merlin7/interactive-jobs.html#Requirements) and
[{Accessing Merlin -> NoMachine}](/merlin7/nomachine.html) for more details. However,
we provide a small recipe for enabling X11 Forwarding in MacOS.

* Ensure that **[XQuartz](https://www.xquartz.org/)** is installed and running in your MacOS.

* For enabling client X11 forwarding, add the following to the start of ``~/.ssh/config``
to implicitly add ``-X`` to all ssh connections:
   
   ```bash
   ForwardAgent yes
   ForwardX11Trusted yes
   ```

* Alternatively, you can add the option ``-Y`` to the ``ssh`` command. In example:

   ```bash
   ssh -X $username@login001.merlin7.psi.ch
   ssh -X $username@login002.merlin7.psi.ch
   ```

* For testing that X11 forwarding works, just run ``sview``. A X11 based slurm view of the cluster should
popup in your client session.

   ```bash
   sview
   ```
