---
title: Remote Desktop Access to Merlin7
keywords: NX, NoMachine, remote desktop access, login node, login001, login002, merlin7-nx-01, merlin7-nx, nx.psi.ch, VPN, browser access
last_updated: 07 August 2024
sidebar: merlin7_sidebar
permalink: /merlin7/nomachine.html
---

## Overview

Merlin7 NoMachine provides users with remote desktop access to the Merlin7 computing environment. This service enables users to connect to their computing resources from any location, whether they are inside the PSI network or accessing from outside via secure methods.

## Accessing Merlin7 NoMachine

### From Inside PSI

If you are inside the PSI network, you can directly connect to the Merlin7 NoMachine service without the need to go through another service.

1. **Ensure Network Connectivity**: Make sure you are connected to the PSI internal network.
2. **Choose Your Access Method**: You can access Merlin7 using either a web browser or the NoMachine client.

#### Method 1: Using a Web Browser

Open your web browser and navigate to [https://merlin7-nx.psi.ch:4443](https://merlin7-nx.psi.ch:4443).

#### Method 2: Using the NoMachine Client

Settings for the NoMachine client:

- **Host**: `merlin7-nx.psi.ch`
- **Port**: `4000`
- **Protocol**: `NX`
- **Authentication**: `Use password authentication`

### From Outside PSI

Users outside the PSI network have two options for accessing the Merlin7 NoMachine service: through `nx.psi.ch` or via a VPN connection.

#### Option 1: Via `nx.psi.ch`

Documentation about the `nx.psi.ch` service can be found [here](https://www.psi.ch/en/photon-science-data-services/remote-desktop-nomachine).

##### Using a Web Browser

Open your web browser and navigate to [https://nx.psi.ch](https://nx.psi.ch).

##### Using the NoMachine Client

Settings for the NoMachine client:

- **Host**: `nx.psi.ch`
- **Port**: `4000`
- **Protocol**: `NX`
- **Authentication**: `Use password authentication`

#### Option 2: Via VPN

Alternatively, you can use a VPN connection to access Merlin7 as if you were inside the PSI network.

1. **Request VPN Access**: Contact the IT department to request VPN access if you do not already have it. Submit a request through the PSI Service Now ticketing system: [VPN Access (PSI employees)](https://psi.service-now.com/psisp?id=psi_new_sc_cat_item&sys_id=beccc01b6f44a200d02a82eeae3ee440).
2. **Connect to the VPN**: Once access is granted, connect to the PSI VPN using your credentials.
3. **Access Merlin7 NoMachine**: Once connected to the VPN, you can access Merlin7 using either a web browser or the NoMachine client as if you were inside the PSI network.

## The NoMachine Client

### Installation

#### Windows

The NoMachine client is available for PSI Windows computers in the Software Kiosk under the name **NX Client**.

#### macOS and Linux

The NoMachine client can be downloaded from [NoMachine's download page](https://downloads.nomachine.com).

### Connection Configuration

1. **Launch NoMachine Client**: Open the NoMachine client on your computer.
2. **Create a New Connection**: Click the **Add** button to create a new connection.
    - On the **Address** tab configure:
      - **Name**: Enter a name for your connection. This can be anything.
      - **Host**: Enter the appropriate hostname (e.g. `merlin7-nx.psi.ch`).
      - **Port**: Enter `4000`.
      - **Protocol**: Select `NX`.

    ![Create New NoMachine Connection]({{ "/images/NoMachine/screen_nx_address.png" }})

    - On the **Configuration** tab ensure:
      - **Authentication**: Select `Use password authentication`.

    ![Create New NoMachine Connection]({{ "/images/NoMachine/screen_nx_configuration.png" }})

    - Click the **Add** button to finish creating the new connection.

## Authenticating

When prompted, use your PSI credentials to authenticate.

![Create New NoMachine Connection]({{ "/images/NoMachine/screen_nx_auth.png" }})

## Managing Sessions

The Merlin7 NoMachine service is managed through a front-end server and back-end nodes, facilitating balanced and efficient access to remote desktop sessions.

### Architecture Overview

- **Front-End Server**: `merlin7-nx.psi.ch`
  - Serves as the entry point for users connecting to the NoMachine service.
  - Handles load-balancing and directs users to available back-end nodes.

- **Back-End Nodes**:
  - `login001.merlin7.psi.ch`
  - `login002.merlin7.psi.ch`
  - These nodes host the NoMachine desktop service and manage the individual desktop sessions.

Access to the login node desktops must be initiated through the `merlin7-nx.psi.ch` front-end. The front-end service will distribute sessions across available nodes in the back-end, ensuring optimal resource usage.

### Opening NoMachine Desktop Sessions

When connecting to the `merlin7-nx.psi.ch` front-end, a new session automatically opens if no existing session is found. Users can manage their sessions as follows:

- **Reconnect to an Existing Session**: If you have an active session, you can reconnect to it by selecting the appropriate icon in the NoMachine client interface. This allows you to resume work without losing any progress.
![Open an existing Session]({{ "/images/NoMachine/screen_nx_single_session.png" }})
- **Create a Second Session**: If you require a separate session, you can select the **`New Desktop`** button. This option creates a second session on another login node, provided the node is available and operational.

### Session Management Considerations

- **Load Balancing**: The front-end service ensures that sessions are evenly distributed across the available back-end nodes to optimize performance and resource utilization.
- **Session Limits**: Users are limited to one session per back-end node to maintain system stability and efficiency.

## Support and Resources

If you encounter any issues or need further assistance with the Merlin7 NoMachine service, support is available via email. Please contact us at [merlin-admins@lists.psi.ch](mailto:merlin-admins@lists.psi.ch), and our support team will be happy to assist you.

### Advanced Display Settings

NoMachine provides several options to optimize the display settings for better performance and clarity. These settings can be accessed and adjusted when creating a new session or by clicking the top right corner of a running session.

#### Prevent Rescaling

Preventing rescaling can help eliminate "blurriness" in your display, though it may affect performance. Adjust these settings based on your performance needs:

- Display: Choose `Resize remote display` (forces 1:1 pixel sizes)
- Display > Change settings > Quality: Choose medium-best quality
- Display > Change settings > Modify the advanced display settings
  - Check: Disable network-adaptive display quality (turns off lossy compression)
  - Check: Disable client side image post-processing
