---
title: ANSYS 
#tags:
keywords: software, ansys, slurm, interactive, rsm, pmodules, overlay, overlays
last_updated: 23 August 2024
summary: "This document describes how to load and use ANSYS in the Merlin7 cluster"
sidebar: merlin7_sidebar
permalink: /merlin7/ansys.html
---

This document describes generic information of how to load and run ANSYS software in the Merlin cluster

## ANSYS software in Pmodules

The ANSYS software can be loaded through **[PModules](/merlin7/pmodules.html)**.

The default ANSYS versions are loaded from the central PModules repository. 

However, we provide local installations on Merlin7 which are needed mainly for some ANSYS packages, like Ansys RSM.
Due to this, and also to improve the interactive experience of the user, ANSYS has been also installed in the 
Merlin high performance storage and we have made it available from Pmodules. 

### Loading Merlin7 ANSYS

For loading the Merlin7 ANSYS software, one needs to run Pmodules v1.1.22 or newer, and then use a specific repository 
(called **`merlin`**) which is **only available from the Merlin7 cluster**:

```bash
module purge
module load Pmodules/1.1.22
module use merlin
module use unstable
module use /etc/cscs-modules/
module load cray
module search ANSYS

# Load the proper ANSYS version, in example for 2022R2
module load ANSYS/2022R2
```
Once `merlin` is invoked, it will disable central ANSYS installations with the same version, which will be replaced
by the local ones in Merlin. Releases from the central Pmodules repository which have not a local installation will remain 
visible. For each ANSYS release, one can identify where it is installed by searching ANSYS in PModules with the `--verbose` 
option. This will show the location of the different ANSYS releases as follows:
* For ANSYS releases installed in the central repositories, the path starts with `/opt/psi`
* For ANSYS releases installed in the Merlin7 repository (and/or overwritting the central ones), the path starts with `/data/software/pmodules`

**We strongly recommend only using ANSYS/2022R2 or superior**.

<details>
<summary>[Example] Loading ANSYS from the Merlin7 PModules repository</summary>
<pre class="terminal code highlight js-syntax-highlight plaintext" lang="plaintext" markdown="false">
🔥 [caubet_m@login001:~]# module purge                                              
🔥 [caubet_m@login001:~]# module load Pmodules/1.1.22                               
module load: unstable module has been loaded -- Pmodules/1.1.22                                                                                                         

🔥 [caubet_m@login001:~]# module use merlin                                         
🔥 [caubet_m@login001:~]# module use unstable                                                                                                                           
🔥 [caubet_m@login001:~]# module use /etc/cscs-modules/                             
🔥 [caubet_m@login001:~]# module load cray                                          
                                                                                    
Activating Modules:                                                                 
  1) cce/17.0.0                                                                     

🔥 [caubet_m@login001:~]# module load ANSYS/2022R2                                                                                                                      
module load: unstable module has been loaded -- ANSYS/2022R2          

🔥 [caubet_m@login001:~]# module search ANSYS --verbose
ANSYS/2019R3:
  release stage: stable
  group:         Tools
  overlay:       base
  modulefile:    /opt/psi/Tools/modulefiles/ANSYS/2019R3
  dependencies:  (none)
ANSYS/2020R1:
  release stage: stable
  group:         Tools
  overlay:       base
  modulefile:    /opt/psi/Tools/modulefiles/ANSYS/2020R1
  dependencies:  (none)
ANSYS/2020R1-1:
  release stage: stable
  group:         Tools
  overlay:       base
  modulefile:    /opt/psi/Tools/modulefiles/ANSYS/2020R1-1
  dependencies:  (none)
ANSYS/2020R2:
  release stage: unstable
  group:         Tools
  overlay:       base
  modulefile:    /opt/psi/Tools/modulefiles/ANSYS/2020R2
  dependencies:  (none)
ANSYS/2021R1:
  release stage: unstable
  group:         Tools
  overlay:       base
  modulefile:    /opt/psi/Tools/modulefiles/ANSYS/2021R1
  dependencies:  (none)
ANSYS/2022R2:
  release stage: unstable
  group:         Tools
  overlay:       merlin
  modulefile:    /data/software/pmodules/Tools/modulefiles/ANSYS/2022R2
  dependencies:  (none)
ANSYS/2023R2:
  release stage: unstable
  group:         Tools
  overlay:       merlin
  modulefile:    /data/software/pmodules/Tools/modulefiles/ANSYS/2023R2
  dependencies:  (none)
ANSYS/2024R1:
  release stage: unstable
  group:         Tools
  overlay:       merlin
  modulefile:    /data/software/pmodules/Tools/modulefiles/ANSYS/2024R1
  dependencies:  (none)
</pre>
</details>


{{site.data.alerts.tip}} Please <b>only use Merlin7 ANSYS installations from `merlin`</b> in the Merlin cluster.
Also, please always run <b>ANSYS/2022R2 or superior</b>.
{{site.data.alerts.end}}

## ANSYS Documentation by product

### ANSYS RSM

**ANSYS Remote Solve Manager (RSM)** is used by ANSYS Workbench to submit computational jobs to HPC clusters directly from Workbench on your desktop.
Therefore, PSI workstations with direct access to Merlin can submit jobs by using RSM.

For further information, please visit the **[ANSYS RSM](/merlin7/ansys-rsm.html)** section.

### ANSYS Fluent

For further information, please visit the **[ANSYS RSM](/merlin7/ansys-fluent.html)** section.

### ANSYS CFX

For further information, please visit the **[ANSYS RSM](/merlin7/ansys-cfx.html)** section.

### ANSYS MAPDL

For further information, please visit the **[ANSYS RSM](/merlin7/ansys-mapdl.html)** section.
